library("lavaan")
library(lavaanPlot)
library(semTools)
library(MVN)

#Multivariate Normality

mvn(dataMVN, mvnTest = "energy")

#Two-Factor

model <- 'A1 =~ FCS1 + FCS2 + FCS4 + FCS5
A2 =~ FCS3 + FCS6 + FCS7
FCS2 ~~ FCS3
FCS7 ~~ FCS2'
result <- sem(model, data = Data)
summary(result, standardized = TRUE)

fit <- lavaan(model, data=Data,
              auto.var=TRUE, auto.fix.first=TRUE,
              auto.cov.lv.x=TRUE, estimator = "DWLS")
summary(fit, fit.measures=TRUE, standardized = TRUE, rsquare = TRUE)
resid(fit, type="standardized")
resid(fit, type="cor")

lavaanPlot(model = fit, node_options = list(shape = "box", fontname = "Helvetica"), edge_options = list(color = "grey"), coefs = T, sig = .05)

#Bifactor

model <- 'A1 =~ FCS1 + FCS2 + FCS4 + FCS5
A2 =~ FCS3 + FCS6 + FCS7
A3 =~ FCS1 + FCS2 + FCS4 + FCS5 + FCS3 + FCS6 + FCS7
A1 ~~ 0*A2
A2 ~~ 0*A3
A1 ~~ 0*A3'
result <- sem(model, data = Data)
summary(result, standardized = TRUE)

fit <- lavaan(model, data=Data,
              auto.var=TRUE, auto.fix.first=TRUE,
              auto.cov.lv.x=TRUE, estimator = "DWLS")
summary(fit, fit.measures=TRUE, standardized = TRUE, rsquare = TRUE)
resid(fit, type="standardized")
resid(fit, type="cor")

lavaanPlot(model = fit, node_options = list(shape = "box", fontname = "Helvetica"), edge_options = list(color = "grey"), coefs = T, sig = .05)

